Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(378)

Unified Diff: components/nacl/browser/nacl_file_host.h

Issue 649603004: Non-SFI NaCl: Batch-open resource files (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Remove ipc/ and mojo/ changes following Mark's suggestion Created 6 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | components/nacl/browser/nacl_file_host.cc » ('j') | components/nacl/browser/nacl_file_host.cc » ('J')
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: components/nacl/browser/nacl_file_host.h
diff --git a/components/nacl/browser/nacl_file_host.h b/components/nacl/browser/nacl_file_host.h
index 11f533378dbe667aac154883918dadacea7fe742..d3953f35a136a6427671f529d2ad86166c81df60 100644
--- a/components/nacl/browser/nacl_file_host.h
+++ b/components/nacl/browser/nacl_file_host.h
@@ -6,6 +6,7 @@
#define COMPONENTS_NACL_BROWSER_NACL_FILE_HOST_H_
#include <string>
+#include <vector>
#include "base/memory/ref_counted.h"
@@ -41,11 +42,12 @@ void GetReadonlyPnaclFd(
bool PnaclCanOpenFile(const std::string& filename,
base::FilePath* file_to_open);
-// Opens a NaCl executable file for reading and executing.
-void OpenNaClExecutable(
+// Opens NaCl resource files for reading and/or executing.
+void OpenNaClResources(
scoped_refptr<nacl::NaClHostMessageFilter> nacl_host_message_filter,
int render_view_id,
- const GURL& file_url,
+ const GURL& executable_file_url,
+ const std::vector<GURL>& resource_urls,
Mark Seaborn 2015/02/02 23:21:50 What is the difference between executable_file_url
Yusuke Sato 2015/02/04 02:00:28 Done.
IPC::Message* reply_msg);
} // namespace nacl_file_host
« no previous file with comments | « no previous file | components/nacl/browser/nacl_file_host.cc » ('j') | components/nacl/browser/nacl_file_host.cc » ('J')

Powered by Google App Engine
This is Rietveld 408576698